@@ -2,18 +2,20 @@ import argparse
 import logging
 import logging.handlers
 import os
+
 import six.moves.configparser as configparser
 
+__version__ = "0.5.3"
+
 # -----------------------------------------------------------------------------
 
 # Parse command line arguments
 parser = argparse.ArgumentParser(
-    description='Downloads a manifest and its media files.')
-parser.add_argument('--config', help='Config file path',
-                    default='manifest-ingest.cfg')
+    description="Downloads a manifest and its media files."
+)
+parser.add_argument("--config", help="Config file path", default="manifest-ingest.cfg")
 # parser.add_argument('-p,', '--password', help='SFTP Password')
-parser.add_argument('-m', '--mode', help='Force download mode',
-                    default='auto')
+parser.add_argument("-m", "--mode", help="Force download mode", default="auto")
 args = parser.parse_args()
 
 # Read config
@@ -26,12 +28,12 @@ logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
 
 # Create logging format
-msg_fmt = '[%(levelname)s] [%(asctime)s] [%(name)s] %(message)s'
-date_fmt = '%Y-%m-%d %I:%M:%S %p'
+msg_fmt = "[%(levelname)s] [%(asctime)s] [%(name)s] %(message)s"
+date_fmt = "%Y-%m-%d %I:%M:%S %p"
 formatter = logging.Formatter(msg_fmt, date_fmt)
 
 # Create file handler
-logfile = os.path.expanduser(config.get('default', 'log'))
+logfile = os.path.expanduser(config.get("default", "log"))
 if not os.path.exists(os.path.dirname(logfile)):
     os.makedirs(os.path.dirname(logfile))
 fh = logging.handlers.RotatingFileHandler(logfile, maxBytes=10485760, backupCount=5)
